use strict;
use warnings FATAL => 'all';
use ExtUtils::MakeMaker;

(do 'maint/Makefile.PL.include' or die $@) unless -f 'META.yml';

require Alien::NQP;

(my $nqp_root = $INC{"Alien/NQP.pm"}) =~ s/\.pm$/\/Install/;

WriteMakefile(
  NAME => 'Alien::Rakudo',
  VERSION_FROM => 'lib/Alien/Rakudo.pm',
  PMLIBDIRS => [ 'lib' ],
  META_MERGE => {
    no_index => { directory => [ 'rakudo' ] },
    configure_requires => { 'Alien::NQP' => 0 }
  },
);

sub MY::postamble { (my $str = <<'END') =~ s{NQP_ROOT}{$nqp_root}g; $str; }

ALIENTARGET=$(INSTALLSITEARCH)/Alien/Rakudo/Install

all :: alienblib
	touch blib/arch/auto/Alien/Rakudo/force-arch

rakudo :
	mkdir -p rakudo
	cd rakudo; tar xzf ../../rakudo-$(RVERSION).tar.gz --strip-components=1
	cd rakudo; patch -p1 <../rakpatch

rakudo/Makefile :
	cd rakudo; $(PERL) Configure.pl --prefix=$(ALIENTARGET) --backends=moar

alieninst : rakudo/Makefile
	cd rakudo; make NQP_PREFIX=NQP_ROOT DESTDIR=../alieninst install

alienblib : alieninst
	mkdir -p blib/lib/Alien/Rakudo/Install
	cp -a alieninst/$(ALIENTARGET)/bin blib/
	cp -a alieninst/$(ALIENTARGET) blib/lib/Alien/Rakudo/
	perl -pi -e '$$_ eq "#!/bin/sh\n" and $$_ .= "export RAKUDO_PREFIX=$(ALIENTARGET)/share/perl6\n"' blib/bin/* blib/lib/Alien/Rakudo/Install/bin/*

clean ::
	cd rakudo; make clean
	rm rakudo/Makefile
	rm -rf alieninst

END
